@@ -161,11 +161,12 @@ import os
 import pathlib
 from typing import Any, Dict, List, Optional, Sequence
 
-from ae.core import DEBUG_LEVEL_VERBOSE, try_eval                               # type: ignore
+from ae.inspector import try_eval                                               # type: ignore
+from ae.core import DEBUG_LEVEL_VERBOSE                                         # type: ignore
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.0.14'
+__version__ = '0.0.15'
 
 
 NODE_FILE_PREFIX = 'node_'  #: file name prefix for node imports/exports
@@ -684,7 +685,7 @@ class LiszDataMixin(ABC):
         if node:
             self.change_sub_node_sel(node, set_sel_to)
         else:
-            assert not set_sel_to == bool(self.current_node_items[node_idx].get('sel', 0))
+            # assert not set_sel_to == bool(self.current_node_items[node_idx].get('sel', 0))
             self.toggle_item_sel(node_idx)
         event_kwargs['flow_id'] = id_of_flow('focus', 'item', item_id)
         return True
